/*
 * Main:
 * Calls four tasks.
 *
 * Printer:
 * Events on data on a channel.
 * Prints this data.
 *
 * Source 1:
 * Generates a number every 3 seconds.
 * Passes this number over its channel.
 *
 * Source 2:
 * Generates a number every 5 seconds.
 * Passes this number over its channel.
 *
 * ASM:
 * Will wait for an event on two channels (each from the two sources).
 * When got a data from a channel, it will send out a source index and the data
 * over the printer channel.
 */
#include <print.h>
#include <timer.h>

extern void asm_event_channel(chanend c_source1, chanend c_source2, chanend c_printer);

/*============================================================================*/
void source(chanend c_source, unsigned delay)
{
  for(int i = 0; i < 10; i++)
  {
    delay_seconds(delay);
    c_source <: i;
  }
}
/*============================================================================*/
void printer(chanend c_printer)
{
  unsigned source, data;
  while(1)
  {
    select
    {
      case c_printer :> source:
      {
        c_printer :> data;
        printstr("Data from source "); printint(source); printstr(" = "); printintln(data);
        break;
      }
    }
  }
}
/*============================================================================*/
int main(void)
{
  chan c_source1, c_source2, c_printer;
  par
  {
    source(c_source1, 3);
    source(c_source2, 5);
    printer(c_printer);
    asm_event_channel(c_source1, c_source2, c_printer);
  }
  return 0;
}
/*============================================================================*/
