/*
 * Main:
 * Calls three tasks.
 *
 * Printer:
 * Events on data on a channel.
 * Prints this data.
 *
 * Tx:
 * Outputs data on a one bit port
 * Outputs a one for 500ms.
 * Outputs a zero for 500ms.
 * Does this 11 times.
 *
 * ASM:
 * Will wait for a pin going high event on a port.
 * When got this event, increments a counter and waits for the port to go low.
 * Sends out the counter value over the printer channel.
 */
#include <xs1.h>
#include <platform.h>
#include <print.h>
#include <timer.h>

on tile[0]: out port p_tx = XS1_PORT_1L;
on tile[1]: in port p_rx = XS1_PORT_1L;

extern void asm_event_port(in port rx, chanend c_printer);

/*============================================================================*/
void tx()
{
  unsigned one = 1, zero = 0;
  p_tx <: zero;
  delay_seconds(1);
  for(int i = 0; i < 11; i++)
  {
    delay_milliseconds(500);
    p_tx <: one;
    delay_milliseconds(500);
    p_tx <: zero;
  }
}
/*============================================================================*/
void printer(chanend c_printer)
{
  unsigned counter;
  while(1)
  {
    select
    {
      case c_printer :> counter:
      {
        printstr("Number of pulses = "); printintln(counter);
        break;
      }
    }
  }
}
/*============================================================================*/
int main()
{
  chan c_printer;
  par
  {
    on tile[0]: tx();
    on tile[1]: asm_event_port(p_rx, c_printer);
    on tile[1]: printer(c_printer);
  }
  return 0;
}
/*============================================================================*/
